@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2010-2018 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -34,26 +34,28 @@
 #ifndef __GUSB_VERSION_H
 #define __GUSB_VERSION_H
 
+#include <glib.h>
+
 /**
  * G_USB_MAJOR_VERSION:
  *
  * The compile-time major version
  */
-#define G_USB_MAJOR_VERSION		(0)
+#define G_USB_MAJOR_VERSION		0
 
 /**
  * G_USB_MINOR_VERSION:
  *
  * The compile-time minor version
  */
-#define G_USB_MINOR_VERSION		(2)
+#define G_USB_MINOR_VERSION		3
 
 /**
  * G_USB_MICRO_VERSION:
  *
  * The compile-time micro version
  */
-#define G_USB_MICRO_VERSION		(9)
+#define G_USB_MICRO_VERSION		1
 
 /**
  * G_USB_CHECK_VERSION:
@@ -67,4 +69,6 @@
      (G_USB_MAJOR_VERSION == (major) && G_USB_MINOR_VERSION == (minor) && \
       G_USB_MICRO_VERSION >= (micro)))
 
+const gchar	*g_usb_version_string	(void);
+
 #endif /* __GUSB_VERSION_H */
